@@ -339,6 +339,28 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_ACTION_BUTCHER,
 	INTERFACEKEY_A_ACTION_ABILITY,
 	INTERFACEKEY_A_ACTION_POWER,
+	INTERFACEKEY_A_ACTION_COMPOSE,
+	INTERFACEKEY_A_ACTION_WRITE,
+	INTERFACEKEY_A_CONSTRUCTION,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_NEW,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_EDIT,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_ASSIGN,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_DELETE,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_RECT,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_FLOW,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE_REMOVE_RECT,
+	INTERFACEKEY_ADV_CONSTRUCTION_STAIR_UPDOWN,
+	INTERFACEKEY_ADV_CONSTRUCTION_REMOVE_PLANS,
+	INTERFACEKEY_ADV_CONSTRUCTION_REMOVE_EXISTING,
+	INTERFACEKEY_ADV_CONSTRUCTION_MATERIAL,
+	INTERFACEKEY_ADV_CONSTRUCTION_CONSTRUCTION,
+	INTERFACEKEY_ADV_CONSTRUCTION_BUILDING,
+	INTERFACEKEY_ADV_CONSTRUCTION_ZONE,
+	INTERFACEKEY_ADV_CONSTRUCTION_WORK_MENU,
+	INTERFACEKEY_ADV_CONSTRUCTION_NAME_SITE,
+	INTERFACEKEY_ADV_CONSTRUCTION_YOU_WORK,
+	INTERFACEKEY_ADV_CONSTRUCTION_START,
+	INTERFACEKEY_A_COMPOSE_FILTER,
 	INTERFACEKEY_A_INV_LOOK,
 	INTERFACEKEY_A_INV_REMOVE,
 	INTERFACEKEY_A_INV_WEAR,
@@ -368,6 +390,11 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_ENTER_NAME,
 	INTERFACEKEY_A_CUST_NAME,
 	INTERFACEKEY_A_RANDOM_NAME,
+	INTERFACEKEY_A_RANDOM_APPEARANCE,
+	INTERFACEKEY_A_RANDOM_APPEARANCE_FULL,
+	INTERFACEKEY_A_RANDOM_PERSONALITY,
+	INTERFACEKEY_A_CUSTOM_PERSONALITY,
+	INTERFACEKEY_A_CHANGE_DREAM,
 	INTERFACEKEY_A_CHANGE_GENDER,
 	INTERFACEKEY_A_END_TRAVEL,
 	INTERFACEKEY_A_TRAVEL_CLOUDS,
@@ -396,6 +423,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_SETUP_EMBARK=EMBARKKEY_START,
 	INTERFACEKEY_SETUP_NAME_FORT,
 	INTERFACEKEY_SETUP_NAME_GROUP,
+	INTERFACEKEY_SETUP_SYMBOL,
 	INTERFACEKEY_SETUP_RECLAIM,
 	INTERFACEKEY_SETUP_FIND,
 	INTERFACEKEY_SETUP_NOTES,
@@ -435,9 +463,12 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDJOB_ADD=BUILDINGKEY_START,
 	INTERFACEKEY_BUILDJOB_CANCEL,
 	INTERFACEKEY_BUILDJOB_PROMOTE,
+	INTERFACEKEY_BUILDJOB_NOW,
 	INTERFACEKEY_BUILDJOB_REPEAT,
 	INTERFACEKEY_BUILDJOB_SUSPEND,
 	INTERFACEKEY_BUILDJOB_WORKSHOP_PROFILE,
+	INTERFACEKEY_BUILDJOB_DETAILS,
+	INTERFACEKEY_BUILDJOB_DETAILS_FILTER,
 	INTERFACEKEY_BUILDJOB_WELL_FREE,
 	INTERFACEKEY_BUILDJOB_WELL_SIZE,
 	INTERFACEKEY_BUILDJOB_TARGET_FREE,
@@ -563,11 +594,13 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_BUILDING_TRADEDEPOT,
 	INTERFACEKEY_HOTKEY_BUILDING_TRAP,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE,
+	INTERFACEKEY_HOTKEY_BUILDING_INSTRUMENT,
 	INTERFACEKEY_HOTKEY_BUILDING_SUPPORT,
 	INTERFACEKEY_HOTKEY_BUILDING_ARCHERYTARGET,
 	INTERFACEKEY_HOTKEY_BUILDING_TRACTION_BENCH,
 	INTERFACEKEY_HOTKEY_BUILDING_SLAB,
 	INTERFACEKEY_HOTKEY_BUILDING_NEST_BOX,
+	INTERFACEKEY_HOTKEY_BUILDING_BOOKCASE,
 	INTERFACEKEY_HOTKEY_BUILDING_HIVE,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_SCREW_PUMP,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_WATER_WHEEL,
@@ -673,6 +706,18 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDINGLIST_ZOOM_T,
 	INTERFACEKEY_BUILDINGLIST_ZOOM_Q,
 	INTERFACEKEY_RECENTER_ON_LEVER,
+	INTERFACEKEY_ASSIGN_LOCATION,
+	INTERFACEKEY_LOCATION_NEW,
+	INTERFACEKEY_LOCATION_RETIRE,
+	INTERFACEKEY_LOCATION_INN_TAVERN,
+	INTERFACEKEY_LOCATION_TEMPLE,
+	INTERFACEKEY_LOCATION_LIBRARY,
+	INTERFACEKEY_LOCATION_MAIN_HALL,
+	INTERFACEKEY_LOCATION_RENAME,
+	INTERFACEKEY_LOCATION_DETAILS,
+	INTERFACEKEY_LOCATION_RESTRICTION,
+	INTERFACEKEY_LOCATION_SET_NUMBER_1,
+	INTERFACEKEY_LOCATION_SET_NUMBER_2,
 
 	WORKSHOPKEY_START,
 	INTERFACEKEY_HOTKEY_MAKE_ASH=WORKSHOPKEY_START,
@@ -693,7 +738,6 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_GLASS_GRATE,
 	INTERFACEKEY_HOTKEY_GLASS_GOBLET,
 	INTERFACEKEY_HOTKEY_GLASS_TOY,
-	INTERFACEKEY_HOTKEY_GLASS_INSTRUMENT,
 	INTERFACEKEY_HOTKEY_GLASS_DOOR,
 	INTERFACEKEY_HOTKEY_GLASS_STATUE,
 	INTERFACEKEY_HOTKEY_GLASS_TABLE,
@@ -764,7 +808,6 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_CRAFTS_SLAB,
 	INTERFACEKEY_HOTKEY_CRAFTS_MAT_CRAFTS,
 	INTERFACEKEY_HOTKEY_CRAFTS_MAT_GOBLET,
-	INTERFACEKEY_HOTKEY_CRAFTS_MAT_INSTRUMENT,
 	INTERFACEKEY_HOTKEY_CRAFTS_MAT_TOY,
 	INTERFACEKEY_HOTKEY_SMITH_WEAPON,
 	INTERFACEKEY_HOTKEY_SMITH_ARMOR,
@@ -877,6 +920,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_STOCKPILE_AMMO,
 	INTERFACEKEY_STOCKPILE_COINS,
 	INTERFACEKEY_STOCKPILE_FINISHED,
+	INTERFACEKEY_STOCKPILE_SHEET,
 	INTERFACEKEY_STOCKPILE_NONE,
 	INTERFACEKEY_STOCKPILE_SETTINGS_ENABLE,
 	INTERFACEKEY_STOCKPILE_SETTINGS_DISABLE,
@@ -919,6 +963,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_STORES_DUMP,
 	INTERFACEKEY_STORES_HIDE,
 	INTERFACEKEY_PET_BUTCHER,
+	INTERFACEKEY_PET_GELD,
 	INTERFACEKEY_ANIMAL_SELECT_TRAINER,
 	INTERFACEKEY_ANIMAL_WAR_TRAINING,
 	INTERFACEKEY_ANIMAL_HUNTING_TRAINING,
@@ -998,6 +1043,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_D_ARTLIST,
 	INTERFACEKEY_D_NOBLES,
 	INTERFACEKEY_D_ORDERS,
+	INTERFACEKEY_D_PETITIONS,
+	INTERFACEKEY_D_LOCATIONS,
 	INTERFACEKEY_D_MILITARY,
 	INTERFACEKEY_D_ROOMS,
 	INTERFACEKEY_D_SQUADS,
@@ -1110,13 +1157,27 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITJOB_REMOVE_CRE,
 	INTERFACEKEY_UNITJOB_ZOOM_CRE,
 	INTERFACEKEY_UNITJOB_ZOOM_BUILD,
-	INTERFACEKEY_UNITJOB_VIEW,
+	INTERFACEKEY_UNITJOB_VIEW_UNIT,
+	INTERFACEKEY_UNITJOB_VIEW_JOB,
 	INTERFACEKEY_UNITJOB_MANAGER,
 	INTERFACEKEY_MANAGER_NEW_ORDER,
 	INTERFACEKEY_MANAGER_REMOVE,
 	INTERFACEKEY_MANAGER_PROMOTE,
 	INTERFACEKEY_MANAGER_MAX,
 	INTERFACEKEY_MANAGER_WAGES,
+	INTERFACEKEY_MANAGER_CONDITIONS,
+	INTERFACEKEY_MANAGER_DETAILS,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ADD_ITEM,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ADD_ORDER,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ITEM_TYPE,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ITEM_MATERIAL,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ITEM_TRAITS,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ITEM_INEQUALITY,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ITEM_NUMBER,
+	INTERFACEKEY_WORK_ORDER_CONDITION_DELETE,
+	INTERFACEKEY_WORK_ORDER_CONDITION_ORDER_ACTIVATION,
+	INTERFACEKEY_WORK_ORDER_CONDITION_REAGENTS,
+	INTERFACEKEY_WORK_ORDER_CONDITION_PRODUCTS,
 	INTERFACEKEY_DESIGNATE_BITEM,
 	INTERFACEKEY_DESIGNATE_CLAIM,
 	INTERFACEKEY_DESIGNATE_UNCLAIM,
@@ -1146,9 +1207,13 @@ enum InterfaceKeyType
 	INTERFACEKEY_DESIGNATE_PLANTS,
 	INTERFACEKEY_DESIGNATE_SMOOTH,
 	INTERFACEKEY_DESIGNATE_ENGRAVE,
+	INTERFACEKEY_DESIGNATE_DETAILS,
 	INTERFACEKEY_DESIGNATE_FORTIFY,
 	INTERFACEKEY_DESIGNATE_TRACK,
 	INTERFACEKEY_DESIGNATE_TOGGLE_ENGRAVING,
+	INTERFACEKEY_DESIGNATE_STANDARD_MARKER,
+	INTERFACEKEY_DESIGNATE_MINE_MODE,
+	INTERFACEKEY_DESIGNATE_TOGGLE_MARKER,
 	INTERFACEKEY_DESIGNATE_UNDO,
 	INTERFACEKEY_DESIGNATE_REMOVE_CONSTRUCTION,
 	INTERFACEKEY_ITEM_DESCRIPTION,
@@ -1169,6 +1234,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITVIEW_FOLLOW,
 	INTERFACEKEY_UNITVIEW_NEXT,
 	INTERFACEKEY_UNITVIEW_SLAUGHTER,
+	INTERFACEKEY_UNITVIEW_GELD,
 	INTERFACEKEY_UNITVIEW_GEN_COMBAT,
 	INTERFACEKEY_UNITVIEW_GEN_LABOR,
 	INTERFACEKEY_UNITVIEW_GEN_MISC,
@@ -1179,8 +1245,12 @@ enum InterfaceKeyType
 	INTERFACEKEY_UNITVIEW_PRF_REMOVE_FROM_SQUAD,
 	INTERFACEKEY_UNITVIEW_PRF_NAME_CURRENT_SQUAD,
 	INTERFACEKEY_UNITVIEW_PRF_NAME_SELECTED_SQUAD,
+	INTERFACEKEY_UNITVIEW_PRF_OCCUPATION,
 	INTERFACEKEY_CUSTOMIZE_UNIT_NICKNAME,
 	INTERFACEKEY_CUSTOMIZE_UNIT_PROFNAME,
+	INTERFACEKEY_IMAGE_CREATOR_FILTER,
+	INTERFACEKEY_IMAGE_CREATOR_NAME,
+	INTERFACEKEY_IMAGE_CREATOR_DONE,
 
 	MILITIAKEY_START,
 	INTERFACEKEY_D_MILITARY_CREATE_SQUAD=MILITIAKEY_START,
